@@ -136,9 +136,13 @@ sub _resolve_captcha ( $self, $url, $res, $cb ) {
 
     $image_url =~ s/&amp;/&/smg;
 
+    $image_url = P->uri( $image_url, base => $base_url );
+
+    my $q = P->data->from_uri_query( $image_url->query )->{'q'};
+
     # get captcha image
     $self->_ua->run(
-        url       => P->uri( $image_url, base => $base_url ),
+        url       => $image_url,
         on_finish => sub ($img_res) {
 
             # resolve captcha
@@ -155,12 +159,13 @@ sub _resolve_captcha ( $self, $url, $res, $cb ) {
                     my $query = P->data->to_uri(
                         {   continue => $url,
                             id       => $id,
+                            q        => $q,
                             submit   => 'Submit',
                             captcha  => $captcha->result
                         }
                     );
 
-                    # enter captchs
+                    # enter captcha
                     $self->_ua->run(
                         url       => P->uri( '/sorry/CaptchaRedirect?' . $query, base => $base_url ),
                         on_finish => sub ($res) {
